@@ -78,10 +78,12 @@ class App(object):
         # uvicorn_logger_init()
         # server.run()
 
+        # uvicorn.config.LOGGING_CONFIG['formatters']['access']['fmt'] = f"""
+        #      🔥 %(asctime)s | {LOCAL_HOST} - %(levelprefix)s %(client_addr)s - "%(request_line)s" %(status_code)s
+        #      """.strip()
         uvicorn.config.LOGGING_CONFIG['formatters']['access']['fmt'] = f"""
-             🔥 %(asctime)s | {LOCAL_HOST} - %(levelprefix)s %(client_addr)s - "%(request_line)s" %(status_code)s
-             """.strip()
-
+              🔥 %(asctime)s - %(levelprefix)s %(client_addr)s - "%(request_line)s" %(status_code)s
+              """.strip()
         uvicorn.run(
             app if app else self.app,
             host=host, port=port, workers=workers, access_log=access_log, debug=debug, **kwargs
