@@ -9,12 +9,19 @@
 # @Description  : 
 
 
-# https://www.jb51.net/article/207138.htm
-import matplotlib.pyplot as plt
-from io import BytesIO
-import streamlit as st
 
-from paddleocr import PaddleOCR
+import numpy as np
+import cv2
+import streamlit as st
+from paddleocr import PaddleOCR, PPStructure, draw_structure_result, save_structure_res
+
+
+@st.experimental_singleton()
+def ppmodel():
+    return PPStructure(show_log=True)
+
+
+table_engine = ppmodel()
 
 uploaded_file = st.file_uploader(label='File uploader')
 
@@ -22,27 +29,10 @@ if uploaded_file is not None:
     st.image(uploaded_file)
 
     bytes_data = uploaded_file.read()
-    import os
-    import cv2
+    np_arr = np.frombuffer(bytes_data, dtype=np.uint8)
+    img = cv2.imdecode(np_arr, cv2.IMREAD_COLOR)
 
-    os.system('rm img__.png')
-
-    with open('img__.png', 'wb') as f:
-        f.write(bytes_data)
-
-    from paddleocr import PPStructure, draw_structure_result, save_structure_res
-
-
-    @st.experimental_singleton()
-    def ppmodel():
-        return PPStructure(show_log=False, use_gpu=False)
-
-
-    table_engine = ppmodel()
-
-    img_data = cv2.imread('img__.png')
-
-    result = table_engine(img_data)
+    result = table_engine(img)
 
     st.markdown(result[0]['res'].replace("""<table>""", """<table style="width: 10px;">"""), True)
 
