@@ -16,7 +16,7 @@ c = Client(host='grpc://0.0.0.0:9955')
 # _ = c.post('/cut', Document()).texts
 # print(_)
 
-print(c.post('/cut', Document(text='我在南京')).tensors)
+print(c.post('/cut', Document(text='我在南京')).texts)
 
 # r = c.post(
 #     '/',
